@@ -1,5 +1,5 @@
 package POEx::Weather::OpenWeatherMap;
-$POEx::Weather::OpenWeatherMap::VERSION = '0.003001';
+$POEx::Weather::OpenWeatherMap::VERSION = '0.003002';
 use Defaults::Modern;
 
 use POE 'Component::Client::HTTP';
@@ -18,7 +18,7 @@ use Weather::OpenWeatherMap::Result::Forecast;
 use Weather::OpenWeatherMap::Request::Find;
 
 
-use Moo; use MooX::late;
+use Moo;
 with 'MooX::Role::POE::Emitter';
 
 
